==> aws-android-sdk-kms-2.8.5-sources.jar: com/amazonaws/services/kms/model/transform/CancelKeyDeletionResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model.transform;

import com.amazonaws.services.kms.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response CancelKeyDeletionResult
 */
public class CancelKeyDeletionResultJsonUnmarshaller implements
        Unmarshaller<CancelKeyDeletionResult, JsonUnmarshallerContext> {

    public CancelKeyDeletionResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        CancelKeyDeletionResult cancelKeyDeletionResult = new CancelKeyDeletionResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("KeyId")) {
                cancelKeyDeletionResult.setKeyId(StringJsonUnmarshaller.getInstance().unmarshall(
                        context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return cancelKeyDeletionResult;
    }

    private static CancelKeyDeletionResultJsonUnmarshaller instance;

    public static CancelKeyDeletionResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CancelKeyDeletionResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-kms-2.13.6-sources.jar: com/amazonaws/services/kms/model/transform/CancelKeyDeletionResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model.transform;

import com.amazonaws.services.kms.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response CancelKeyDeletionResult
 */
public class CancelKeyDeletionResultJsonUnmarshaller implements
        Unmarshaller<CancelKeyDeletionResult, JsonUnmarshallerContext> {

    public CancelKeyDeletionResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        CancelKeyDeletionResult cancelKeyDeletionResult = new CancelKeyDeletionResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("KeyId")) {
                cancelKeyDeletionResult.setKeyId(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return cancelKeyDeletionResult;
    }

    private static CancelKeyDeletionResultJsonUnmarshaller instance;

    public static CancelKeyDeletionResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CancelKeyDeletionResultJsonUnmarshaller();
        return instance;
    }
}
